@@ -58,7 +58,9 @@
 #include <pqc_resolutioncache.h>
 #include <pqc_windowgeometry.h>
 #include <pqc_location.h>
+#ifdef PQMPHOTOSPHERE
 #include <pqc_photosphere.h>
+#endif
 #include <scripts/pqc_scriptsconfig.h>
 #include <scripts/pqc_scriptsfilespaths.h>
 #include <scripts/pqc_scriptsfiledialog.h>
@@ -107,9 +109,19 @@
 #include <QSGRendererInterface>
 #endif
 
+#ifdef PQMFLATPAKBUILD
+#include <gio/gio.h>
+#endif
+
 int main(int argc, char *argv[]) {
 
 #ifdef Q_OS_WIN
+
+#ifdef PQMEXIV2
+    // Exiv2 0.28.x and above needs this locale in order to support proper unicode (e.g., CJK characters) in file names/paths
+    setlocale(LC_ALL, ".UTF8");
+#endif
+
     QFileInfo f(argv[0]);
     qputenv("PATH", QString("%1;%2").arg(qgetenv("PATH"),f.absolutePath().replace("/", "\\")).toLocal8Bit());
     qputenv("MAGICK_CODER_MODULE_PATH", QString("%1").arg(f.absolutePath().replace("/", "\\") + "\\imagemagick\\coders").toLocal8Bit());
@@ -130,6 +142,9 @@ int main(int argc, char *argv[]) {
     QApplication::setApplicationVersion(PQMVERSION);
     QApplication::setQuitOnLastWindowClosed(true);
 
+    // Set the desktop filename. On Wayland this is necessary to set the icon in the window title and panel
+    QGuiApplication::setDesktopFileName("org.photoqt.PhotoQt.desktop");
+
     // custom message handler for qDebug/qLog/qInfo/etc.
     qInstallMessageHandler(pqcMessageHandler);
 
@@ -168,6 +183,12 @@ int main(int argc, char *argv[]) {
     #endif
 #endif
 
+#ifdef PQMFLATPAKBUILD
+    #if !GLIB_CHECK_VERSION(2,35,0)
+        g_type_init();
+    #endif
+#endif
+
     PQCStartup startup;
     PQCValidate validate;
 
@@ -292,7 +313,9 @@ int main(int argc, char *argv[]) {
     engine.addImageProvider("imgurhistory", new PQCAsyncImageProviderImgurHistory);
     engine.addImageProvider("svg", new PQCProviderSVG);
 
+#ifdef PQMPHOTOSPHERE
     qmlRegisterType<PQCPhotoSphere>("PQCPhotoSphere", 1, 0, "PQCPhotoSphere");
+#endif
 
 #ifdef PQMVIDEOMPV
     qmlRegisterType<PQCMPVObject>("PQCMPVObject", 1, 0, "PQCMPVObject");
