@@ -413,7 +413,8 @@ int PQCSettings::migrate(QString oldversion) {
     /*************************************************************************/
 
     QStringList versions;
-    versions << "4.0" << "4.1" << "4.2";
+    versions << "4.0" << "4.1" << "4.2" << "4.3" << "4.4";
+    // when removing the 'dev' value, check below for any if statement involving 'dev'!
 
     // this is a safety check to make sure we don't forget the above check
     if(oldversion != "dev" && versions.indexOf(oldversion) == -1 && !oldversion.startsWith("3")) {
@@ -421,11 +422,11 @@ int PQCSettings::migrate(QString oldversion) {
     }
 
     int iVersion = 0;
-    if(oldversion != "" && versions.contains(oldversion))
+    if(oldversion == "dev")
+        iVersion = versions.length()-1;
+    else if(oldversion != "" && versions.contains(oldversion))
         // we do a +1 as we are on the found version and don't need to migrate to it
         iVersion = versions.indexOf(oldversion)+1;
-    else if(oldversion == "dev")
-        iVersion = versions.length()-1;
 
     // we iterate through all migrations one by one
 
@@ -459,6 +460,34 @@ int PQCSettings::migrate(QString oldversion) {
 
             }
 
+        } else if(curVer == "4.4") {
+
+            QSqlQuery query(db);
+
+            if(!query.exec("SELECT `value` FROM `filedialog` WHERE `name`='PreviewColorIntensity'"))
+                qCritical() << "Unable to get current PreviewColorIntensity value:" << query.lastError().text();
+            else {
+
+                query.next();
+
+                int val = query.value(0).toInt();
+
+                // if it's larger than that something went wrong
+                if(val <= 10) {
+
+                    QSqlQuery queryUpdate(db);
+                    queryUpdate.prepare("UPDATE `filedialog` SET `value`=:val WHERE `name`='PreviewColorIntensity'");
+                    queryUpdate.bindValue(":val", val*10);
+                    if(!queryUpdate.exec())
+                        qCritical() << "ERROR updating PreviewColorIntensity value:" << queryUpdate.lastError().text();
+                    queryUpdate.clear();
+
+                }
+
+                query.clear();
+
+            }
+
         }
 
         ////////////////////////////////////
