@@ -240,7 +240,7 @@ void PQCShortcuts::readDB() {
 
     while(query.next()) {
 
-        const QString combo = query.value(0).toString();
+        QString combo = query.value(0).toString();
         const QStringList commands = query.value(1).toString().split(":://::");
         const int cycle = query.value(2).toInt();
         int cycletimeout = query.value(3).toInt();
@@ -249,6 +249,8 @@ void PQCShortcuts::readDB() {
         if(cycle == 0 && simultaneous == 0)
             cycletimeout = 1;
 
+        if(combo == "Del") combo = "Delete";
+
         shortcuts[combo] = QVariantList() << commands << cycle << cycletimeout << simultaneous;
         shortcutsOrder.push_back(combo);
 
@@ -407,14 +409,6 @@ void PQCShortcuts::resetCommandCycle(QString combo) {
     commandCycle.remove(combo);
 }
 
-QString PQCShortcuts::convertKeyCodeToText(int id) {
-
-    qDebug() << "args: id =" << id;
-
-    return QKeySequence(id).toString();
-
-}
-
 bool PQCShortcuts::migrate(QString oldversion) {
 
     qDebug() << "args: oldversion =" << oldversion;
@@ -429,7 +423,8 @@ bool PQCShortcuts::migrate(QString oldversion) {
     /*************************************************************************/
 
     QStringList versions;
-    versions << "4.0" << "4.1" << "4.2";
+    versions << "4.0" << "4.1" << "4.2" << "4.3" << "4.4";
+    // when removing the 'dev' value, check below for any if statement involving 'dev'!
 
     // this is a safety check to make sure we don't forget the above check
     if(oldversion != "dev" && versions.indexOf(oldversion) == -1) {
@@ -437,11 +432,11 @@ bool PQCShortcuts::migrate(QString oldversion) {
     }
 
     int iVersion = 0;
-    if(oldversion != "" && versions.contains(oldversion))
+    if(oldversion == "dev")
+        iVersion = versions.length()-1;
+    else if(oldversion != "" && versions.contains(oldversion))
         // we do a +1 as we are on the found version and don't need to migrate to it
         iVersion = versions.indexOf(oldversion)+1;
-    else if(oldversion == "dev")
-        iVersion = versions.length()-1;
 
     // we iterate through all migrations one by one
 
@@ -510,6 +505,62 @@ bool PQCShortcuts::migrate(QString oldversion) {
 
             query.clear();
 
+        } else if(curVer == "4.4") {
+
+            // Update 'Del' to 'Delete'
+
+            // first update shortcut set to exactly 'Del'
+            QSqlQuery query(db);
+            if(!query.exec("Update `shortcuts` SET `combo`='Delete' WHERE `combo`='Del'"))
+                qWarning() << "Unable to change 'Del' shortcut to 'Delete':" << query.lastError().text();
+            query.clear();
+
+            // next we update the ones with 'Del' no at the end
+            QSqlQuery query2(db);
+            if(query2.exec("SELECT `combo` FROM `shortcuts` WHERE combo LIKE 'Del+%'")) {
+
+                while(query2.next()) {
+
+                    QString combo = query2.value(0).toString();
+                    QString comboNEW = query2.value(0).toString().replace("Del+", "Delete+");
+
+                    QSqlQuery queryUpd(db);
+                    queryUpd.prepare("UPDATE `shortcuts` SET `combo`=:combonew WHERE `combo`=:combo");
+                    queryUpd.bindValue(":combonew", comboNEW);
+                    queryUpd.bindValue(":combo", combo);
+                    if(!queryUpd.exec())
+                        qWarning() << "Unable to update 'Del' to 'Delete' in shortcut" << combo << "::" << queryUpd.lastError().text();
+                    queryUpd.clear();
+
+                }
+
+            }
+
+            query2.clear();
+
+            // next we update the ones with 'Del' at the end
+            if(query.exec("SELECT `combo` FROM `shortcuts` WHERE combo LIKE '%+Del'")) {
+
+                while(query.next()) {
+
+                    QString combo = query.value(0).toString();
+                    QString comboNEW = combo.replace("+Del", "+Delete");
+
+                    QSqlQuery queryUpd(db);
+                    queryUpd.prepare("UPDATE `shortcuts` SET `combo`=:combonew WHERE `combo`=:combo");
+                    queryUpd.bindValue(":combonew", comboNEW);
+                    queryUpd.bindValue(":combo", combo);
+                    queryUpd.exec();
+                    if(queryUpd.lastError().text().trimmed().length())
+                        qWarning() << "Unable to update 'Del' to 'Delete' in shortcut" << combo << "::" << queryUpd.lastError().text();
+                    queryUpd.clear();
+
+                }
+
+            }
+
+            query.clear();
+
         }
 
     }
