@@ -20,23 +20,24 @@
  **                                                                      **
  **************************************************************************/
 
-#include <QTimer>
+#include <QCollator>
+#include <QDir>
+#include <QFileInfo>
+#include <QFileSystemWatcher>
 #include <QMimeDatabase>
 #include <QSize>
-#include <QFileSystemWatcher>
-#include <QtDebug>
-#include <QFileInfo>
-#include <QDir>
-#include <QCollator>
+#include <QTimer>
 #include <QtConcurrent>
+#include <QtDebug>
+#include <pqc_configfiles.h>
 #include <pqc_filefoldermodel.h>
 #include <pqc_imageformats.h>
-#include <pqc_settings.h>
 #include <pqc_loadimage.h>
 #include <pqc_notify.h>
-#include <scripts/pqc_scriptsimages.h>
-#include <scripts/pqc_scriptsfiledialog.h>
 #include <pqc_resolutioncache.h>
+#include <pqc_settings.h>
+#include <scripts/pqc_scriptsfiledialog.h>
+#include <scripts/pqc_scriptsimages.h>
 
 #ifdef PQMLIBARCHIVE
 #include <archive.h>
@@ -136,6 +137,7 @@ QString PQCFileFolderModel::getFileInFolderMainView() {
     return m_fileInFolderMainView;
 }
 void PQCFileFolderModel::setFileInFolderMainView(QString val) {
+
     if(m_fileInFolderMainView == val)
         return;
     QFileInfo oldfile(m_fileInFolderMainView);
@@ -481,6 +483,7 @@ void PQCFileFolderModel::advancedSortMainView() {
                     if(item == "exiforiginal" || item == "exifdigital") {
 
 #ifdef PQMEXIV2
+
 #if EXIV2_TEST_VERSION(0, 28, 0)
                         Exiv2::Image::UniquePtr image;
 #else
@@ -909,7 +912,10 @@ void PQCFileFolderModel::loadDataMainView() {
 
     } else if(m_readArchiveOnly) {// && PQCImageFormats::get().getEnabledFormatsLibArchive().contains(QFileInfo(m_fileInFolderMainView).suffix().toLower())) {
 
-        m_entriesMainView = PQCScriptsImages::get().listArchiveContent(m_fileInFolderMainView);
+        if(archiveContentPreloaded.length() > 0) {
+            m_entriesMainView = archiveContentPreloaded;
+            archiveContentPreloaded.clear();
+        }
         m_countMainView = m_entriesMainView.length();
         m_readArchiveOnly = false;
         setCurrentIndex(numberPageDocument);
@@ -1180,15 +1186,19 @@ QStringList PQCFileFolderModel::getAllFiles(QString folder, bool ignoreFiltersEx
 
                     }
 
-                    if((m_nameFilters.size() == 0 || (!ignoreFiltersExceptDefault && m_nameFilters.contains(f.suffix().toLower()))) && (m_restrictToSuffixes.size() == 0 || m_restrictToSuffixes.contains(f.suffix().toLower()))) {
+                    QString suffix = f.suffix().toLower();
+                    if(f.isSymLink() && f.exists())
+                        suffix = QFileInfo(f.symLinkTarget()).suffix().toLower();
+
+                    if((m_nameFilters.size() == 0 || (!ignoreFiltersExceptDefault && m_nameFilters.contains(suffix))) && (m_restrictToSuffixes.size() == 0 || m_restrictToSuffixes.contains(suffix))) {
                         if(m_filenameFilters.length() == 0 || ignoreFiltersExceptDefault) {
                             // we need to exclude video files connected to Apple Live Videos (if support enabled)
-                            if(PQCSettings::get()["filetypesLoadAppleLivePhotos"].toBool() && f.suffix().toLower() == "mov" && QFileInfo::exists(f.absolutePath()+"/"+f.baseName()+".heic"))
+                            if(PQCSettings::get()["filetypesLoadAppleLivePhotos"].toBool() && suffix == "mov" && QFileInfo::exists(f.absolutePath()+"/"+f.baseName()+".heic"))
                                 continue;
                             ret_cur << f.absoluteFilePath();
                         } else {
                             // we need to exclude video files connected to Apple Live Videos (if support enabled)
-                            if(PQCSettings::get()["filetypesLoadAppleLivePhotos"].toBool() && f.suffix().toLower() == "mov" && QFileInfo::exists(f.absolutePath()+"/"+f.baseName()+".heic"))
+                            if(PQCSettings::get()["filetypesLoadAppleLivePhotos"].toBool() && suffix == "mov" && QFileInfo::exists(f.absolutePath()+"/"+f.baseName()+".heic"))
                                 continue;
                             for(const QString &fil : std::as_const(m_filenameFilters)) {
                                 if(f.baseName().contains(fil)) {
@@ -1315,15 +1325,18 @@ bool PQCFileFolderModel::isUserFilterSet() {
             m_fileSizeFilter > 0);
 }
 
-void PQCFileFolderModel::enableViewerMode() {
+void PQCFileFolderModel::enableViewerMode(int page) {
 
-    qDebug() << "";
+    qDebug() << "args: page =" << page;
 
     if(PQCScriptsImages::get().isPDFDocument(getCurrentFile()))
-        setFileInFolderMainView("0::PDF::" + getCurrentFile());
-    else
-        setFileInFolderMainView("0::ARC::" + getCurrentFile());
+        setFileInFolderMainView(QString("%1::PDF::%2").arg(page).arg(getCurrentFile()));
+    else {
+        archiveContentPreloaded = PQCScriptsImages::get().listArchiveContent(getCurrentFile());
+        setFileInFolderMainView(QString("%1::ARC::%2").arg(archiveContentPreloaded[page], getCurrentFile()));
+    }
     forceReloadMainView();
+    setCurrentIndex(page);
 }
 
 void PQCFileFolderModel::disableViewerMode() {
