@@ -74,6 +74,10 @@
 #include <exiv2/exiv2.hpp>
 #endif
 
+#ifdef PQMLCMS2
+#include <lcms2.h>
+#endif
+
 PQCScriptsConfig::PQCScriptsConfig() {
     trans = new QTranslator;
     currentTranslation = "en";
@@ -163,6 +167,10 @@ QString PQCScriptsConfig::getConfigInfo(bool formatHTML) {
     txt += QString(" - %1Video%2 through Qt%3").arg(bold1, bold2, nl);
 #endif
 
+#ifdef PQMLCMS2
+    txt += QString(" - %1LittleCMS%2: %3%4").arg(bold1, bold2).arg(LCMS_VERSION).arg(nl);
+#endif
+
 #ifdef PQMVIDEOMPV
     mpv_handle *mpv = mpv_create();
     if(mpv_initialize(mpv) < 0)
@@ -504,8 +512,22 @@ bool PQCScriptsConfig::isFreeImageSupportEnabled() {
     return false;
 }
 
-bool PQCScriptsConfig::isPopplerSupportEnabled() {
-#ifdef PQMPOPPLER
+bool PQCScriptsConfig::isPDFSupportEnabled() {
+#if defined PQMPOPPLER||PQMQTPDF
+    return true;
+#endif
+    return false;
+}
+
+bool PQCScriptsConfig::isLibVipsSupportEnabled() {
+#ifdef PQMLIBVIPS
+    return true;
+#endif
+    return false;
+}
+
+bool PQCScriptsConfig::isLibArchiveSupportEnabled() {
+#ifdef PQMLIBARCHIVE
     return true;
 #endif
     return false;
@@ -619,3 +641,24 @@ bool PQCScriptsConfig::isMotionPhotoSupportEnabled() {
 #endif
     return false;
 }
+
+bool PQCScriptsConfig::isPhotoSphereSupportEnabled() {
+#ifdef PQMPHOTOSPHERE
+    return true;
+#endif
+    return false;
+}
+
+bool PQCScriptsConfig::isZXingSupportEnabled() {
+#ifdef PQMZXING
+    return true;
+#endif
+    return false;
+}
+
+bool PQCScriptsConfig::isLCMS2SupportEnabled() {
+#ifdef PQMLCMS2
+    return true;
+#endif
+    return false;
+}
