@@ -48,6 +48,10 @@
 #include <exiv2/exiv2.hpp>
 #endif
 
+#ifdef PQMFLATPAKBUILD
+#include <gio/gio.h>
+#endif
+
 PQCScriptsFileManagement::PQCScriptsFileManagement() {}
 
 PQCScriptsFileManagement::~PQCScriptsFileManagement() {}
@@ -115,7 +119,31 @@ bool PQCScriptsFileManagement::moveFileToTrash(QString filename) {
     }
     return ret;
 #else
+
+#ifndef PQMFLATPAKBUILD
+
+    // this does not work with Flatpak, checked 2024-04-03
     return QFile::moveToTrash(filename);
+
+#else
+
+    // for flatpaks we use GIO trash function as this has support for the trash portal
+
+    GFile *file = g_file_new_for_path(filename.toStdString().c_str());
+    GError *error = nullptr;
+    bool success = g_file_trash(file, nullptr, &error);
+
+    if(!success) {
+        qWarning() << "Failed to move file to trash:" << error->message;
+        g_error_free(error);
+    }
+
+    g_object_unref(file);
+
+    return success;
+
+#endif
+
 #endif
 
 }
@@ -274,30 +302,25 @@ void PQCScriptsFileManagement::scaleImage(QString sourceFilename, QString target
         Exiv2::XmpData xmpData;
         bool gotExifData = false;
 
+#if EXIV2_TEST_VERSION(0, 28, 0)
+        Exiv2::Image::UniquePtr image_read;
+#else
+        Exiv2::Image::AutoPtr image_read;
+#endif
+
         try {
 
     // Open image for exif reading
     #if EXIV2_TEST_VERSION(0, 28, 0)
-            Exiv2::Image::UniquePtr image_read = Exiv2::ImageFactory::open(sourceFilename.toStdString());
+            image_read = Exiv2::ImageFactory::open(sourceFilename.toStdString());
     #else
-            Exiv2::Image::AutoPtr image_read = Exiv2::ImageFactory::open(sourceFilename.toStdString());
+            image_read = Exiv2::ImageFactory::open(sourceFilename.toStdString());
     #endif
 
             if(image_read.get() != 0) {
-
                 // YAY, WE FOUND SOME!!!!!
                 gotExifData = true;
-
-                // read exif
                 image_read->readMetadata();
-                exifData = image_read->exifData();
-                iptcData = image_read->iptcData();
-                xmpData = image_read->xmpData();
-
-                // Update dimensions
-                exifData["Exif.Photo.PixelXDimension"] = int32_t(targetSize.width());
-                exifData["Exif.Photo.PixelYDimension"] = int32_t(targetSize.height());
-
             }
 
         }
@@ -306,6 +329,19 @@ void PQCScriptsFileManagement::scaleImage(QString sourceFilename, QString target
             qDebug() << "ERROR reading exif data (caught exception):" << e.what();
         }
 
+        if(gotExifData) {
+
+            // read exif
+            exifData = image_read->exifData();
+            iptcData = image_read->iptcData();
+            xmpData = image_read->xmpData();
+
+            // Update dimensions
+            exifData["Exif.Photo.PixelXDimension"] = int32_t(targetSize.width());
+            exifData["Exif.Photo.PixelYDimension"] = int32_t(targetSize.height());
+
+        }
+
     #endif
 
         // We need to do the actual scaling in between reading the exif data above and writing it below,
