@@ -59,6 +59,10 @@ QString PQCScriptsFilesPaths::cleanPath(QString path) {
     else if(path.startsWith("image://thumb/"))
         path = path.remove(0, 14);
 
+    QFileInfo info(path);
+    if(info.isSymLink() && info.exists())
+        path = info.symLinkTarget();
+
     return QDir::cleanPath(path);
 #endif
 
@@ -77,19 +81,20 @@ QString PQCScriptsFilesPaths::cleanPath_windows(QString path) {
     else if(path.startsWith("image://thumb/"))
         path = path.remove(0, 14);
 
-    bool networkPath = path.startsWith("//");
-    path = QDir::cleanPath(path);
-    if(networkPath)
-        path = "/"+path;
+    QFileInfo info(path);
+    if(info.isSymLink() && info.exists())
+        path = info.symLinkTarget();
 
-    return path;
+    return QDir::cleanPath(path);
 
 }
 
 QString PQCScriptsFilesPaths::pathWithNativeSeparators(QString path) {
 
 #ifdef Q_OS_WIN
-    while(path.startsWith("/"))
+    if(path.startsWith("\\\\") && path.mid(3,1) == ":")
+        path = path.mid(2);
+    else if(path.startsWith("\\") && path.mid(2,1) == ":")
         path = path.mid(1);
 #endif
 
@@ -100,7 +105,9 @@ QString PQCScriptsFilesPaths::pathWithNativeSeparators(QString path) {
 QString PQCScriptsFilesPaths::pathFromNativeSeparators(QString path) {
 
 #ifdef Q_OS_WIN
-    while(path.startsWith("\\"))
+    if(path.startsWith("\\\\") && path.mid(3,1) == ":")
+        path = path.mid(2);
+    else if(path.startsWith("\\") && path.mid(2,1) == ":")
         path = path.mid(1);
 #endif
 
@@ -195,9 +202,17 @@ QString PQCScriptsFilesPaths::getWindowsDriveLetter(QString path) {
 
 QStringList PQCScriptsFilesPaths::getFoldersIn(QString path) {
 
+    qDebug() << "args: path =" << path;
+
     if(path == "")
         return QStringList();
 
+#ifdef Q_OS_WIN
+    // Without this the top level folder list shows the folders in the application directory
+    if(!path.endsWith("/"))
+        path = path + "/";
+#endif
+
     QDir dir(path);
 
     dir.setFilter(QDir::Dirs|QDir::NoDotAndDotDot);
@@ -344,7 +359,7 @@ QString PQCScriptsFilesPaths::selectFileFromDialog(QString buttonlabel, QString
     diag.setOption(QFileDialog::DontUseNativeDialog, false);
     diag.setNameFilter("*."+endings.join(" *.") + ";;All Files (*.*)");
     diag.setDirectory(info.absolutePath());
-    diag.selectFile(info.baseName() + "." + endings[0]);
+    diag.selectFile(info.completeBaseName() + "." + endings[0]);
 
     if(diag.exec()) {
         QStringList fileNames = diag.selectedFiles();
@@ -638,3 +653,9 @@ void PQCScriptsFilesPaths::cleanupTemporaryFiles() {
         dir.removeRecursively();
 
 }
+
+bool PQCScriptsFilesPaths::isUrl(QString path) {
+
+    return (path.startsWith("http://") || path.startsWith("https://") || path.startsWith("ftp://") || path.startsWith("ftps://"));
+
+}
