@@ -21,10 +21,13 @@
  **************************************************************************/
 
 #include <scripts/pqc_scriptsmetadata.h>
+#include <pqc_configfiles.h>
+#include <pqc_imageformats.h>
 
 #include <QtDebug>
 #include <QPointF>
 #include <QVariant>
+#include <QFileInfo>
 
 #ifdef PQMEXIV2
 #include <exiv2/exiv2.hpp>
@@ -683,3 +686,102 @@ void PQCScriptsMetaData::setFaceTags(QString filename, QVariantList tags) {
 #endif
 
 }
+
+int PQCScriptsMetaData::getExifOrientation(QString path) {
+
+    qDebug() << "args: path =" << path;
+
+#ifdef PQMEXIV2
+
+#if EXIV2_TEST_VERSION(0, 28, 0)
+    Exiv2::Image::UniquePtr image;
+#else
+    Exiv2::Image::AutoPtr image;
+#endif
+    try {
+        image  = Exiv2::ImageFactory::open(path.toStdString());
+        image->readMetadata();
+    } catch (Exiv2::Error& e) {
+        // An error code of kerFileContainsUnknownImageType (older version: 11) means unknown file type \
+        // Since we always try to read any file's meta data, this happens a lot
+#if EXIV2_TEST_VERSION(0, 28, 0)
+        if(e.code() != Exiv2::ErrorCode::kerFileContainsUnknownImageType)
+#else
+        if(e.code() != 11)
+#endif
+            qWarning() << "ERROR reading exif data (caught exception):" << e.what();
+        else
+            qDebug() << "ERROR reading exif data (caught exception):" << e.what();
+
+        return 1;
+    }
+
+    Exiv2::ExifData exifData;
+
+    try {
+        exifData = image->exifData();
+    } catch(Exiv2::Error &e) {
+        qDebug() << "ERROR: Unable to read exif metadata:" << e.what();
+        return 1;
+    }
+
+    Exiv2::ExifData::iterator iter = exifData.findKey(Exiv2::ExifKey("Exif.Image.Orientation"));
+    if(iter != exifData.end()) {
+
+        const int val = QString::fromStdString(Exiv2::toString(iter->value())).toInt();
+        if(val >= 1 && val <= 8)
+            return val;
+
+    }
+
+#endif
+
+    return 1;
+
+}
+
+bool PQCScriptsMetaData::areFaceTagsSupported(QString filename) {
+
+    qDebug() << "args: filename =" << filename;
+
+#ifdef PQMEXIV2
+
+    if(filename.contains("::PDF::") || filename.contains("::ARC::"))
+        return false;
+
+    const QString suffix = QFileInfo(filename).suffix().toLower();
+    if(!PQCImageFormats::get().getEnabledFormatsQt().contains(suffix) &&
+        !PQCImageFormats::get().getEnabledFormatsMagick().contains(suffix)) {
+        return false;
+    }
+
+#if EXIV2_TEST_VERSION(0, 28, 0)
+    Exiv2::Image::UniquePtr image;
+#else
+    Exiv2::Image::AutoPtr image;
+#endif
+    try {
+        image  = Exiv2::ImageFactory::open(filename.toStdString());
+        image->readMetadata();
+        Exiv2::XmpData &xmpDataOld = image->xmpData();
+    } catch (Exiv2::Error& e) {
+        // An error code of 11 means image not supported. This is much more reliable than, e.g., checking a file ending
+#if EXIV2_TEST_VERSION(0, 28, 0)
+        if(e.code() != Exiv2::ErrorCode::kerFileContainsUnknownImageType)
+#else
+        if(e.code() != 11)
+#endif
+            qWarning() << "ERROR reading metadata:" << e.what();
+        else
+            qDebug() << "ERROR reading metadata:" << e.what();
+        return false;
+    }
+
+    // if we got here then we can read/write xmp exif data
+    return true;
+
+#endif
+
+    return false;
+
+}
